#include <avr/io.h>
#include "MMA8452.h"
#include <math.h>
#include "nokia5110.h"
#include <stdio.h>
#include <util/delay.h>
#include "dhtxx.h"
#define BAUD 9600
#define MYUBRR F_CPU/16/BAUD-1

void USART0_init(unsigned int ubrr)
{
	/* seteaza baud rate la 9600 */
	UBRR0H = 0;
	UBRR0L = 103;
	//UBRR0H = (unsigned char)(ubrr>>8);
	//UBRR0L = (unsigned char)ubrr;
	/* porneste transmitatorul */
	UCSR0B = (1<<TXEN0) | (1<<RXEN0);

	/* seteaza formatul frame-ului: 8 biti de date, 1 biti de stop, paritate para */
	//UCSR0C &= ~(1<<USBS0);
	UCSR0C |= (3<<UCSZ00) | 1<<USBS0;
	//UCSR0C |= (1<<UPM01);
}

void USART0_transmit(char data)
{
	/* asteapta pana bufferul e gol */
	while(!(UCSR0A & (1<<UDRE0)));

	/* pune datele in buffer; transmisia va porni automat in urma scrierii */
	UDR0 = data;
}

/*
 * Functie ce transmite un sir de caractere prin USART
 *
 * @param data - sirul (terminat cu '\0') de transmis
 */
void USART0_print(const char *data)
{
	while(*data != '\0')
		USART0_transmit(*data++);
}



int main()
{
	USART0_init(MYUBRR);

	i2c_init();

	nokia_lcd_init();
	MMA8452 accel;

	if (accel.init() == false) {

		nokia_lcd_clear();
		nokia_lcd_set_cursor(0, 10);
		nokia_lcd_write_string("Fail", 3);
		nokia_lcd_render();
		while(1) _delay_ms(1000);
	} else {

		accel.setDataRate(MMA_400hz);
		accel.setRange(MMA_RANGE_2G);
		accel.setMotionDetectionMode(MMA_MOTION, MMA_ALL_AXIS);
		accel.setMotionTreshold(0x11);
	}
	accel.setDataRate(MMA_800hz);
	accel.setRange(MMA_RANGE_8G);
	uint8_t i,j;
	int t;
	uint8_t plot[84];
	for(i = 0; i < 84; i++)
		plot[i] = 2;

	uint8_t u = 0, k = 0, l = 0;
	char buf[30];
	int temp, humid;
	while(1){
		bool motion = accel.motionDetected();


		for(t = 0 ; t < 100; t++) {

			nokia_lcd_clear();
			sprintf(buf,"READY %dK %d%%",temp/10+ 273, humid/10);

			nokia_lcd_write_string(buf, 1);
			for(i = 0; i < k; i++)
				// draw_pixel is your routine for plotting an individual pixel 
				for(j = 0; j < plot[i]; j++)
					nokia_lcd_set_pixel(i,48 - j, 1);

			if (motion)
			{
				USART0_print("motion");	
				//nokia_lcd_set_cursor(0, 30);
				//nokia_lcd_set_cursor(10, 30);
				//nokia_lcd_write_string("|", 2);
				l = l + 1;

			}
			else {

				//nokia_lcd_set_cursor(0, 10);
				//nokia_lcd_write_string("-", 3);
			}
			if(u == 0) {
				plot[k] = l;
				l = 2;
				k = (k + 1) % 84;
			}
			u = (u + 1) % 20;


			nokia_lcd_render();
			_delay_ms(50);
		}
	
		dhtxxconvert( DHTXX_DHT11, &PORTA, &DDRA, &PINA, ( 1 << 0 ) );
		_delay_ms(1000);
		dhtxxread( DHTXX_DHT11, &PORTA, &DDRA, &PINA, ( 1 << 0 ), &temp, &humid );

	}

}
